@@ -16,25 +16,39 @@
 ##' default is NULL;
 ##' @return nothing
 ##' @author Gionata Bocci <boccigionata@@gmail.com>>
-local_storage<-function(db=c("LEDA","AMF"),directory){
+local_storage<-function(db=c("LEDA","Akhmetzhanova","MycoFlor"),directory){
 
     dir.create(directory,showWarnings=FALSE)
 
     
     ## download AMF data
-    if("AMF"%in%db){
+    if("Akhmetzhanova"%in%db){
         myco_url <- "http://esapubs.org/Archive/ecol/E093/059/myco_db.csv"
-        myco<- tryCatch(read.csv(myco_url,sep=",",header=T),
+        myco<- tryCatch(read.csv(myco_url,sep=",",header=TRUE),
                         error=function(res){
                             message("URL does not seem to exist:")
                             return(NA)},
                         warning=function(res){
                             message("URL does not seem to exist:")
                             return(NA)
-                        } )
+                        })
         save(file=paste(directory,"myco.Rda",sep="/"),myco,precheck = F) 
     }
-    
+
+    if("MycoFlor"%in%db){
+        mycoflor_url<-"http://www.esapubs.org/archive/ecol/E094/123/MycoFlor.txt"
+        MycoFlor<- tryCatch(read.delim(mycoflor_url,header=TRUE),
+                            error=function(res){
+                                message("URL does not seem to exist:")
+                                return(NA)},
+                            warning=function(res){
+                                message("URL does not seem to exist:")
+                                return(NA)
+                            } )
+        save(file=paste(directory,"MycoFlor.Rda",sep="/"),MycoFlor,precheck = F) 
+    }
+
+     
     if("LEDA"%in%db){
         ## download LEDA data
         leda_download_to_local_directory(directory)
