@@ -258,7 +258,7 @@ tr8<-function(species_list,download_list=NULL,gui_config=FALSE){
                 ## run the gui
                 traits_list<-tr8_config()
             }else{
-                for(db in c("BiolFlor","LEDA","Ecoflora","Pignatti","Akhmetzhanova")){
+                for(db in c("BiolFlor","LEDA","Ecoflora","Pignatti","AMF")){
                     #db<-temp_dframe$db[temp_dframe$short_code==i]
                     data_db<-temp_dframe[temp_dframe$db==db,]
                     if(sum(data_db$short_code%in%download_list)>0){
@@ -296,24 +296,52 @@ tr8<-function(species_list,download_list=NULL,gui_config=FALSE){
         ## add AMF
         ## if AMF is not already downloaded, local_storage is run (but only
         ## if this trait is requred
-        local_amf<-paste(directory,"myco.Rda",sep="/")
-        if(file.exists(local_amf)){
-            load(local_amf)}else{
-
-                if(length(traits_list$Akhmetzhanova)>0){
-                    local_storage(db="AMF",directory)
+        TRAIT_AK="Akhmetzhanova"
+        ##is the user interested in downloadin Akhmetzhanova?
+        if("Myco_infection"%in%traits_list$AMF){
+            ## then check if the dataset has already been downloaded
+            local_amf<-paste(directory,"myco.Rda",sep="/")
+            if(file.exists(local_amf)){
+                load(local_amf)}else{
+                    ## otherwise download it now
+                    local_storage(db="Akhmetzhanova",directory)
                     load(local_amf)
-                }else{myco<-NULL}
-            }
+                }
+        }else{myco<-NULL
+              TRAIT_AK<-NULL
+          }
+    
+        amf_traits<-retrieve_amf(species_list,TRAITS=TRAIT_AK,rest=rest,data_myco=myco)
+
+        ## check&download mycoflor
+
+        TRAIT_MYC="MycoFlor"
+        ##is the user interested in downloadin MycoFlor?
+        if("MycoFlor"%in%traits_list$AMF){
+
+            ## then check if the dataset has already been downloaded
+            local_amf<-paste(directory,"MycoFlor.Rda",sep="/")
+            if(file.exists(local_amf)){
+                load(local_amf)}else{
+                    ## otherwise download it now
+                    local_storage(db="MycoFlor",directory)
+                    load(local_amf)
+                }
+        }else{
+            MycoFlor<-NULL
+            TRAIT_MYC<-NULL
+        }
+
+        amf_MycoFlor<-retrieve_MycoFlor(species_list,TRAITS=TRAIT_MYC,rest=rest,data_myco=MycoFlor)
 
 
-        amf_traits<-retrieve_amf(species_list,TRAITS=traits_list$Akhmetzhanova,rest=rest,myco=myco)
+        
         
         ## merge the results
         tr8_traits<-data.frame(species_list,row.names=species_list)
         bibliography=list()
         
-        for(i in c(eco_traits,biolflor_traits,leda_traits,pignatti_traits,it_flowering,amf_traits)){
+        for(i in c(eco_traits,biolflor_traits,leda_traits,pignatti_traits,it_flowering,amf_traits,amf_MycoFlor)){
             ## merge the dataframes only if they contain data
             if(!is.null(i@results))
                 {
@@ -356,3 +384,4 @@ tr8<-function(species_list,download_list=NULL,gui_config=FALSE){
     }
 }
 
+
